@@ -1,12 +1,8 @@
 import os
-from os.path import join
-import warnings
 
 
 def configuration(parent_package='', top_path=None):
     from numpy.distutils.misc_util import Configuration
-    from numpy.distutils.system_info import get_info, BlasNotFoundError
-    import numpy
 
     libraries = []
     if os.name == 'posix':
@@ -14,9 +10,13 @@ def configuration(parent_package='', top_path=None):
 
     config = Configuration('pastis', parent_package, top_path)
     config.add_subpackage('utils')
+    config.add_subpackage("optimization")
+    config.add_subpackage("externals")
+    config.add_subpackage("datasets")
+    config.add_subpackage("io")
     return config
 
+
 if __name__ == '__main__':
     from numpy.distutils.core import setup
     setup(**configuration(top_path='').todict())
-
